==> nextcloud-app-bookmarks-1%3a1.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/it.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Segnalibri",
    "Add a Bookmark" : "Aggiungi un segnalibro",
    "Add folder" : "Aggiungi cartella",
    "Select" : "Seleziona",
    "Deselect" : "Deseleziona",
    "Details" : "Dettagli",
    "Delete" : "Elimina",
    "Saved" : "Salvato",
    "Date added" : "Data aggiunta",
    "Link" : "Collegamento",
    "Tags" : "Etichette",
    "Description" : "Descrizione",
    "No bookmarks here." : "Qui non c'è alcun segnalibro",
    "Favorites" : "Preferiti",
    "Settings" : "Impostazioni",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName} " : "Aggiungi a {instanceName} ",
    "Recently added" : "Aggiunti di recente",
    "Most visited" : "Più visitati",
    "View mode" : "Modalità di visualizzazione",
    "List view" : "Vista a elenco",
    "RSS Feed" : "Fonte RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Rimuovi definitivamente tutti i segnalibri dal tuo account. Non si torna indietro!",
    "Delete all bookmarks" : "Elimina tutti i segnalibri",
    "Open details" : "Apri i dettagli",
    "An error occurred while trying to save the bookmark." : "Si è  verificato un errore durante il tentativo di salvataggio del segnalibro.",
    "Error" : "Errore",
    "Uncategorized" : "Senza categoria",
    "Error parsing the import result" : "Errore durante l'elaborazione del risultato dell'importazione",
    "Import completed successfully." : "Importazione completata correttamente.",
    "Do you really want to delete all your bookmarks?" : "Vuoi davvero eliminare tutti i tuoi segnalibri?",
    "Set tags" : "Imposta etichette",
    "Failed to import one bookmark, because: " : "Importazione di un segnalibro non riuscita, motivo:",
    "No file provided for import" : "Nessun file fornito per l'importazione",
    "Unsupported file type for import" : "Tipo di file non supportato per l'importazione",
    "A Bookmark manager for Nextcloud" : "Un gestore di segnalibri per Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Questa applicazione ti consente di archiviare e organizzare i tuoi siti preferiti sul web in un solo posto, mentre ti consente di sincronizzarli con i tuoi svariati dispositivi e browser.\nVerifica i client di terze parti elencati qui: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Aggiungi un segnalibro",
    "This URL is already bookmarked! Overwrite?" : "Questo URL è già un segnalibro! Vuoi sovrascriverlo?",
    "The title of the page" : "Il titolo della pagina",
    "The address of the page" : "L'indirizzo della pagina",
    "Description of the page" : "Descrizione della pagina",
    "Save" : "Salva",
    "Previews" : "Anteprime",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Per visualizzare le schermate effettive dei tuoi siti web preferiti, Segnalibri può utilizzare un servizio di terze parti per generarle.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Puoi registrarti gratuitamente su <a href=\"http://screeenly.com\">screeenly.com</a> o <a href=\"https://github.com/stefanzweifel/screeenly\">configurare il tuo server</a>.",
    "Screeenly API URL" : "URL API di Screenly",
    "Screeenly API key" : "Chiave API di Screenly",
    "Bookmarks feed" : "Fonte dei segnalibri"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3a2.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/it.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Segnalibri",
    "Add a Bookmark" : "Aggiungi un segnalibro",
    "Add folder" : "Aggiungi cartella",
    "Select" : "Seleziona",
    "Deselect" : "Deseleziona",
    "Details" : "Dettagli",
    "Delete" : "Elimina",
    "Saved" : "Salvato",
    "Date added" : "Data aggiunta",
    "Link" : "Collegamento",
    "Tags" : "Etichette",
    "Description" : "Descrizione",
    "No bookmarks here." : "Qui non c'è alcun segnalibro",
    "Favorites" : "Preferiti",
    "Settings" : "Impostazioni",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName} " : "Aggiungi a {instanceName} ",
    "Recently added" : "Aggiunti di recente",
    "Most visited" : "Più visitati",
    "View mode" : "Modalità di visualizzazione",
    "List view" : "Vista a elenco",
    "RSS Feed" : "Fonte RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Rimuovi definitivamente tutti i segnalibri dal tuo account. Non si torna indietro!",
    "Delete all bookmarks" : "Elimina tutti i segnalibri",
    "Open details" : "Apri i dettagli",
    "An error occurred while trying to save the bookmark." : "Si è  verificato un errore durante il tentativo di salvataggio del segnalibro.",
    "Error" : "Errore",
    "Uncategorized" : "Senza categoria",
    "Error parsing the import result" : "Errore durante l'elaborazione del risultato dell'importazione",
    "Import completed successfully." : "Importazione completata correttamente.",
    "Do you really want to delete all your bookmarks?" : "Vuoi davvero eliminare tutti i tuoi segnalibri?",
    "Set tags" : "Imposta etichette",
    "Not allowed to access folder to import into" : "Non è consentito accedere alla cartella per l'importazione",
    "Failed to import one bookmark, because: " : "Importazione di un segnalibro non riuscita, motivo:",
    "No file provided for import" : "Nessun file fornito per l'importazione",
    "Unsupported file type for import" : "Tipo di file non supportato per l'importazione",
    "A Bookmark manager for Nextcloud" : "Un gestore di segnalibri per Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Questa applicazione ti consente di archiviare e organizzare i tuoi siti preferiti sul web in un solo posto, mentre ti consente di sincronizzarli con i tuoi svariati dispositivi e browser.\nVerifica i client di terze parti elencati qui: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Aggiungi un segnalibro",
    "This URL is already bookmarked! Overwrite?" : "Questo URL è già un segnalibro! Vuoi sovrascriverlo?",
    "The title of the page" : "Il titolo della pagina",
    "The address of the page" : "L'indirizzo della pagina",
    "Description of the page" : "Descrizione della pagina",
    "Save" : "Salva",
    "Previews" : "Anteprime",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Per visualizzare le schermate effettive dei tuoi siti web preferiti, Segnalibri può utilizzare un servizio di terze parti per generarle.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Puoi registrarti gratuitamente su <a href=\"http://screeenly.com\">screeenly.com</a> o <a href=\"https://github.com/stefanzweifel/screeenly\">configurare il tuo server</a>.",
    "Screeenly API URL" : "URL API di Screenly",
    "Screeenly API key" : "Chiave API di Screenly",
    "Bookmarks feed" : "Fonte dei segnalibri"
},
"nplurals=2; plural=(n != 1);");
